<?php

    //
    // Copyright (c) 2002-2003 Zyneo HB. (http://www.zyneo.com)
    // See LICENSE distributed with this package for more information.
    //

    /**
     * $Id: Base.php,v 1.1.1.1 2003/03/27 10:27:43 maro Exp $
     *
     * This class provides some basic utility methods used by most of
     * the classes in the PHP-SDK package.
     *
     * @author Magnus Rosenquist, Zyneo
     * @package base
     * 
     */
        
    class Base
    {

        var $clazz;
        var $method;
        /**
         * debug - logstatements above and including 'debug' are printed.
         * info  - logstatements above and including 'info' are printed.
         * warn  - logstatements above and including 'warn' are printed.
         * fatal - logstatements above and including 'warn' are printed.
         */
        var $loglevel = _DEBUG_LEVEL;
        var $loglevels = array ("debug" => 0,
                                "info"  => 1,
                                "warn"  => 2,
                                "fatal" => 3);
        /**
         * 0 - log to screen
         * 1 - log to file
         * 2 - log to file and screen
         */
        var $logoutput = _DEBUG_OUTPUT;
        var $logFile = _DEBUG_FILE;

        function Base()
        {
            $this->method = "Unknown";
            $this->clazz  = "Unknown";
        }

        function registerClass($clazz)
        {
            $this->clazz = $clazz;
            $this->RegisteredErrors["errors"] = false;
        }

        function registerMethod($method)
        {
            $this->method = $method;
            $this->logDebug("", 1);
        }

        function setLoglevel($level="info")
        {
            $this->loglevel = $level;
        }


        function logInfo($msg)
        {
            $level = $this->loglevels["info"];
            $current = $this->loglevels[$this->loglevel];
            if ( $level >= $current )
                $this->dbg("INFO: ".$msg);
        }
        
        function logDebug($msg)
        {
            $level = $this->loglevels["debug"];
            $current = $this->loglevels[$this->loglevel];
            if ( $level >= $current )
                $this->dbg("DEBUG: ".$msg);
        }
        function logWarn($msg)
        {
            $level = $this->loglevels["warn"];
            $current = $this->loglevels[$this->loglevel];
            if ( $level >= $current )
                $this->dbg("WARN: " .$msg);
        }
        function logFatal($msg)
        {
            $level = $this->loglevels["fatal"];
            $current = $this->loglevels[$this->loglevel];
            if ( $level >= $current )
                $this->dbg("FATAL: " .$msg);
        }

        function dbg($msg, $type=0)
        {
            if ( $this->logoutput == 2 )
            {
                $this->toScreen($msg);
                $this->toFile($msg);
            }
            else if ( $this->logoutput == 1 )
                $this->toFile($msg, $type);
            else if ( $this->logoutput == 0 )
                $this->toScreen($msg);
        }
        
        function toScreen($msg)
        {
            $now = strftime("%Y-%m-%d %T", time());
            print "\n[".$now."] " .$msg;
        }
        
        function toFile($msg, $type=0)
        {
            if ( $this->method != "" )
            {
                if ( $type == 1 )
                    $method = "->".$this->method;
                else
                    $method = "::".$this->method;
            }
            else
                $method = "";
            $now = strftime("%Y-%m-%d %T", time());
            $fp = fopen(_DOCROOT . "/" .$this->logFile, "a");
            fputs($fp, "[".$now."] [".$this->clazz .$method."] " .$msg."\n");
            fclose($fp);
        }

        function formatShortDate($date)
        {
            $stringDate = strtotime($date);
            return ( strftime("%Y-%m-%d", $stringDate ) );
        }

        function formatShortDateTime($date)
        {
            $stringDate = strtotime($date);
            return ( strftime("%Y-%m-%d %H:%M", $stringDate ) );
        }

        function formatLongDate($date)
        {
            $stringDate = strtotime($date);
            return ( strftime("%A-%d-%B-%Y", $stringDate ) );
        }

        function formatLongDateTime($date)
        {
            $stringDate = strtotime($date);
            return ( strftime("%A-%d-%B-%Y, %H:%M", $stringDate ) );
        }


  }






?>
